==> apache-seata-2.1.0-incubating-src.tar.gz: apache-seata-2.1.0-incubating-src/common/src/test/java/org/apache/seata/common/holder/ObjectHolderTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.seata.common.holder;

import org.apache.seata.common.exception.ShouldNeverHappenException;
import org.junit.jupiter.api.AfterEach;
import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;


public class ObjectHolderTest {

    @BeforeEach
    void setUp() {
        ObjectHolder.INSTANCE.setObject("objectHolderTest", this);
    }

    @AfterEach
    void tearDown() {
    }

    @Test
    public void testGetObjectByName() {
        Assertions.assertNotNull(ObjectHolder.INSTANCE.getObject("objectHolderTest"));
        // object not exist in ObjectHolder.INSTANCE
        Assertions.assertNull(ObjectHolder.INSTANCE.getObject("objectHolder"));
    }

    @Test
    public void testGetObjectByClass() {
        Assertions.assertNotNull(ObjectHolder.INSTANCE.getObject(ObjectHolderTest.class));
        // object not exist in ObjectHolder.INSTANCE
        Assertions.assertThrows(ShouldNeverHappenException.class,
            () -> ObjectHolder.INSTANCE.getObject(ObjectHolder.class));
    }
}

==> apache-seata-2.6.0-incubating-src.tar.gz: apache-seata-2.6.0-incubating-src/common/src/test/java/org/apache/seata/common/holder/ObjectHolderTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.seata.common.holder;

import org.apache.seata.common.exception.ShouldNeverHappenException;
import org.junit.jupiter.api.AfterEach;
import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;

public class ObjectHolderTest {

    @BeforeEach
    void setUp() {
        ObjectHolder.INSTANCE.setObject("objectHolderTest", this);
    }

    @AfterEach
    void tearDown() {}

    @Test
    public void testGetObjectByName() {
        Assertions.assertNotNull(ObjectHolder.INSTANCE.getObject("objectHolderTest"));
        // object not exist in ObjectHolder.INSTANCE
        Assertions.assertNull(ObjectHolder.INSTANCE.getObject("objectHolder"));
    }

    @Test
    public void testGetObjectByClass() {
        Assertions.assertNotNull(ObjectHolder.INSTANCE.getObject(ObjectHolderTest.class));
        // object not exist in ObjectHolder.INSTANCE
        Assertions.assertThrows(
                ShouldNeverHappenException.class, () -> ObjectHolder.INSTANCE.getObject(ObjectHolder.class));
    }
}
